$rabbit_user = "deploytracker"
$rabbit_vhost = "deploytracker"
$rabbit_host = "localhost"
$rabbit_port = "5672"

$wsgi_user = "deploytracker"
$wsgi_processes = 2
$wsgi_threads = 2

$postgres_user = "deploytracker"
$postgres_database = "deploytracker"
$postgres_host = "localhost"
$postgres_port = "5432"

$unix_user = "deploytracker"

$py = "$::basedir/bin/py"

$squid_port = "3128"
$combo_port = "8080"

package { "squid":
    ensure => 'installed',
}

package { "libapache2-mod-wsgi":
    ensure => 'installed',
}

package { "apache2":
    ensure => 'installed',
    require => Package["libapache2-mod-wsgi"],
}

package { "rabbitmq-server":
    ensure => 'installed',
}

package { "postgresql-9.1":
    ensure => 'installed',
}

package { "postgresql-client-9.1":
    ensure => 'installed',
    require => Package["postgresql-9.1"],
}

group {$unix_user:
   ensure => 'present',
}

user {$unix_user:
   comment => 'This user was created by Puppet',
   ensure => 'present',
   gid => $unix_user,
   require => Group[$unix_user],
}

exec { "psql-create-user-$postgres_user":
  command => "psql -c \"create user $postgres_user with password '$::postgres_password'\"",
  path => ["/usr/bin", "/bin"],
  user => "postgres",
  unless => "psql -c \"select usename from pg_user where usename = '$postgres_user'\" | grep -q $postgres_user",
  require => Package["postgresql-client-9.1"],
}

exec { "psql-create-database-$postgres_database":
  command => "psql -c 'create database $postgres_database owner $postgres_user'",
  path => ["/usr/bin", "/bin"],
  user => "postgres",
  require => [
    Exec["psql-create-user-$postgres_user"],
    Package["postgresql-client-9.1"],
  ],
  unless => "psql -c \"select datname from pg_database where datname = '$postgres_database'\" | grep -q $postgres_database",
}

exec { "psql-grant-all-$postgres_database-$postgres_user":
  command => "psql -c 'grant all privileges on database $postgres_database to $postgres_user'",
  path => ["/usr/bin"],
  user => "postgres",
  require => [
    Exec["psql-create-database-$postgres_database"],
    Package["postgresql-client-9.1"],
  ],
}

file { "$::basedir/django_project/local_settings.py":
  content => template("local_settings.py.erb"),
  owner => $unix_user,
  group => $unix_user,
  mode => 640,
  require => [
      Group[$unix_user],
      Exec["psql-grant-all-$postgres_database-$postgres_user"],
  ],
}

file { "$::basedir/oopses":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/logs":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/static/":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/branches/":
  owner => $unix_user,
  group => $unix_user,
  mode => 755,
  ensure => directory,
}

file { "$::basedir/celery.log":
  owner => $unix_user,
  group => $unix_user,
  mode => 644,
  ensure => present,
}

file { "$::basedir/celery.pid":
  owner => $unix_user,
  group => $unix_user,
  mode => 644,
  ensure => present,
}

exec { "enable-mod-proxy":
  user => root,
  command => "/usr/sbin/a2enmod proxy",
  unless => "/usr/bin/stat -t /etc/apach2/mods-enabled/proxy.load",
  require => Package["apache2"],
}

exec { "enable-mod-proxy-http":
  user => root,
  command => "/usr/sbin/a2enmod proxy_http",
  unless => "/usr/bin/stat -t /etc/apach2/mods-enabled/proxy_http.load",
  require => Package["apache2"],
}

exec { "enable-mod-expires":
  user => root,
  command => "/usr/sbin/a2enmod expires",
  unless => "/usr/bin/stat -t /etc/apach2/mods-enabled/expires.load",
  require => Package["apache2"],
}

exec { "enable-mod-headers":
  user => root,
  command => "/usr/sbin/a2enmod headers",
  unless => "/usr/bin/stat -t /etc/apach2/mods-enabled/headers.load",
  require => Package["apache2"],
}

file { "/etc/apache2/httpd.conf":
  content => template("httpd.conf.erb"),
}

$celeryd_default_file = "/etc/default/deploy-tracker-celeryd"

file { "/etc/init.d/deploy-tracker-celeryd":
  content => template("celeryd.initscript.erb"),
  mode => 755,
  owner => root,
}

file { $celeryd_default_file:
  content => template("celeryd.default.erb"),
  owner => root,
  mode => 644,
}

exec { "rabbit-add-user-$rabbit_user":
  command => "rabbitmqctl add_user $rabbit_user $::rabbit_password",
  path => ["/sbin", "/usr/sbin", "/bin", "/usr/bin"],
  user => root,
  unless => "rabbitmqctl list_users | grep -q \"\\<$rabbit_user\\>\"",
  require => Package["rabbitmq-server"],
}

exec { "rabbit-add-vhost-$rabbit_vhost":
  command => "rabbitmqctl add_vhost $rabbit_vhost",
  path => ["/sbin", "/usr/sbin", "/bin", "/usr/bin"],
  user => root,
  unless => "rabbitmqctl list_vhosts | grep -q \"\\<$rabbit_vhost\\>\"",
  require => Package["rabbitmq-server"],
}

exec { "rabbit-set-permissions-$rabbit_vhost-$rabbit_user":
  command => "rabbitmqctl set_permissions -p $rabbit_vhost $rabbit_user .\\* .\\* .\\*",
  path => ["/sbin", "/usr/sbin", "/bin", "/usr/bin"],
  user => root,
  require => [
    Exec["rabbit-add-user-$rabbit_user"],
    Exec["rabbit-add-vhost-$rabbit_vhost"],
    Package["rabbitmq-server"],
  ],
  unless => "rabbitmqctl list_permissions -p $rabbit_vhost | grep -q \"^\\<$rabbit_user\\>\"",
}

file { "/etc/init/deploy-tracker-combo.conf":
  content => template("combo.init.erb"),
  owner => root,
  mode => 644,
}

file { "/etc/squid3/squid.conf":
  content => template("squid.conf.erb"),
  owner => root,
  mode => 644,
  require => Package["squid"],
}
