from functools import wraps
import json

from django.contrib.auth.views import redirect_to_login
from django.http import (
    HttpResponse,
    HttpResponseForbidden,
    )

from .rendering import render_page
from .templating import render_template


def ajax_response(data):
    serialized = json.dumps(data)
    return HttpResponse(serialized, content_type='application/json')


def check_user_allowed(function):
    # XXX: tests
    @wraps(function)
    def _wrapped_view(request, *args, **kwargs):
        user = request.user
        if not user.is_authenticated():
            return redirect_to_login(request.path)
        if not user.is_active:
            return HttpResponseForbidden("Not allowed here")
        if not user.groups.exists():
            content = render_template('no_group.html', {})
            return HttpResponseForbidden(
                render_page("Forbidden", "Forbidden", content, request))
        return function(request, *args, **kwargs)
    return _wrapped_view
