#!/bin/bash

set -eu

# Ensure we can use kubectl snap
export PATH=${PATH}:/snap/bin

CONTAINER_NAME=${JOB_BASE_NAME}
PROJECT_NAME=isitdeployable
IMAGE_NAME=ols/isitdeployable

function lxc_run() {
    cmd=$1
    echo "INFO: Running command \"${cmd}\" in container \"${CONTAINER_NAME}\""
    lxc exec ${CONTAINER_NAME} -- bash -c "${cmd}"
}

function lxc_wait_for_ip() {
    timeout=30
    i=0
    echo -n "INFO: Waiting for container to get IP address.."
    set +e
    while true; do
        sleep 1
        lxc list ${CONTAINER_NAME} -c 4|grep eth
        if [ $? -eq 0 ];then
            set -e
            return
        else
            echo -n "."
            let i+=1 
        fi
        if [ ${i} -ge ${timeout} ]; then
            echo "ERROR: Timeout out waiting for container IP" 
            exit 1
        fi
    done
}

function recreate_lxc() {
    set +e
    echo "INFO: Checking if container exists"
    lxc list|grep ${CONTAINER_NAME}
    if [ $? -eq 0 ];then
        echo "INFO: Found old container, deleting"
        lxc delete --force ${CONTAINER_NAME}
    fi
    set -e
    lxc launch ubuntu:16.04 ${CONTAINER_NAME}
    lxc_run "mkdir -m 700 /root/.ssh"
    echo "INFO: Pushing config to the container"
    lxc file push --uid=0 --gid=0 ~/.ssh/id_rsa ${CONTAINER_NAME}/root/.ssh/
    lxc file push --uid=0 --gid=0 ~/.ssh/config ${CONTAINER_NAME}/root/.ssh/
    lxc_wait_for_ip
    lxc_run "apt update && apt -y install make bzr"
#    lxc_run "bzr launchpad-login jenkaas-is-bot"
}

echo "INFO: Recreating container \"${CONTAINER_NAME}\""
recreate_lxc

# Get code, store revno needed for docker image build
echo "INFO: Branching ${PROJECT_NAME} code: \"${BRANCH}\""
lxc_run "bzr branch ${BRANCH} ${PROJECT_NAME}"
REVNO=$(lxc_run "bzr revno ${PROJECT_NAME}"|grep -v "INFO")
echo "INFO: REVNO: \"${REVNO}\""

echo "INFO: Running tests"
lxc_run "cd ${PROJECT_NAME} && make docker-bootstrap"
lxc_run "cd ${PROJECT_NAME} && make docker-build docker-test"

# If we got this far tests are fine, we can build docker images
if [ -d "${PROJECT_NAME}" ];then
    rm -r ${PROJECT_NAME}
fi

TAG=$(echo ${BRANCH} | \
      sed -e "s/${PROJECT_NAME}//" \
          -e "s/lp:~*//" \
          -e "s@bzr+ssh://bazaar.launchpad.net/+branch/@@" \
          -e "s@bzr+ssh://bazaar.launchpad.net/~@@" \
          -e "s@//@/@g" \
          -e "s@/@-@g" \
          -e "s/-*$//" # ensure no trailing - \
     )
set +u
if [ -z "${TAG}" ];then
    TAG=trunk
fi
set -u

bzr branch ${BRANCH} -r ${REVNO} ${PROJECT_NAME}
echo "INFO: Building ${PROJECT_NAME} docker image tagged ${TAG}"
cd ${PROJECT_NAME} && IMAGES_TAG=${TAG}-${REVNO} make k8s-build

set +e
echo "${RELEASE_TARGET}"|grep "${IMAGE_NAME}"
#if [ $? -eq 0 ]; then
#    echo "INFO: Releasing to \"${RELEASE_TARGET}\""
#    INSTANCE=${RELEASE_TARGET} IMAGE="${IMAGE_NAME}:${TAG}-${REVNO}" make release
#else
    echo "INFO: RELEASE_TARGET not set. To release into prod by hand run:"
    echo "INSTANCE=${IMAGE_NAME} IMAGE=\"${IMAGE_NAME}:${TAG}-${REVNO}\" make release"
#fi
set -e

cd ..
echo "INFO: Cleaning up"
rm -r ${PROJECT_NAME}
lxc delete --force ${CONTAINER_NAME}
